*******************************************************************************
* Wait, there’s torture in Zootopia?: Examining the prevalence of 			  *
*		torture in popular movies   										  *
* Perspectives on Politics													  *
* Casey Delehanty & Erin M. Kearns                 							  *
* Replication Materials         										      *
*******************************************************************************

****************************METHODS SECTION*************************************

//////////////////////////////////////DATA/////////////////////////////////////

**Gross per Movie
*use file: PoP.GrossPerMovie.dta
tab est_ticket_sales
sum est_ticket_sales, detail

**Torture Scenes per Movie
*use file: PoP.Movie.NumberScenes.Rating.dta
tab num_torture_scenes
	tab num_torture_scenes if mpaa_rating==1
	tab num_torture_scenes if mpaa_rating==2
	tab num_torture_scenes if mpaa_rating==3
	tab num_torture_scenes if mpaa_rating==4
sum num_torture_scenes
  	sum num_torture_scenes if mpaa_rating==1
	sum num_torture_scenes if mpaa_rating==2
	sum num_torture_scenes if mpaa_rating==3
	sum num_torture_scenes if mpaa_rating==4
tab total_gross
pwcorr num_torture_scenes total_gross, sig


/////////////////////////////////WHAT TORTURE IS///////////////////////////////

**Public Official Coding
*use file: PoP.MainData.dta
tab public_official_coding


///////////////////////////////MOVIE-LEVEL FACTORS/////////////////////////////

**Number of Torture Scenes per Movie by Rating
*use file: PoP.Movie.NumberScenes.Rating.dta
tab num_torture_scenes if mpaa_rating==1
tab num_torture_scenes if mpaa_rating==2
tab num_torture_scenes if mpaa_rating==3
tab num_torture_scenes if mpaa_rating==4


/////////////////////////////INCIDENT-LEVEL FACTORS////////////////////////////

**Number of Torture Scenes
*use file: PoP.MainData.dta
tab torture
tab torture if mpaa_rating==1
tab torture if mpaa_rating==2
tab torture if mpaa_rating==3
tab torture if mpaa_rating==4

**Goals
*use file: PoP.MainData.dta
tab torture_goal_rc
tab torture_goal_rc if mpaa_rating==1
tab torture_goal_rc if mpaa_rating==2
tab torture_goal_rc if mpaa_rating==3
tab torture_goal_rc if mpaa_rating==4

**Outcome
*use file: PoP.MainData.dta
tab efficacy_rc
tab efficacy_rc if mpaa_rating==1
tab efficacy_rc if mpaa_rating==2
tab efficacy_rc if mpaa_rating==3
tab efficacy_rc if mpaa_rating==4

**Type
*use file: PoP.MainData.dta
tab torture_type_rc
tab torture_type_rc if mpaa_rating==1
tab torture_type_rc if mpaa_rating==2
tab torture_type_rc if mpaa_rating==3
tab torture_type_rc if mpaa_rating==4


////////////////////////////PERPETRATOR-LEVEL FACTORS///////////////////////////

*use file: PoP.MainData.dta
*Perpatrator: Protagonist
tab perp_protagonist
tab perp_protagonist if mpaa_rating==1
tab perp_protagonist if mpaa_rating==2
tab perp_protagonist if mpaa_rating==3
tab perp_protagonist if mpaa_rating==4

*Perpatrator: Antagonist
tab perp_antagonist
tab perp_antagonist if mpaa_rating==1
tab perp_antagonist if mpaa_rating==2
tab perp_antagonist if mpaa_rating==3
tab perp_antagonist if mpaa_rating==4

*Perpatrator: White
tab perp_white
tab perp_white if mpaa_rating==1
tab perp_white if mpaa_rating==2
tab perp_white if mpaa_rating==3
tab perp_white if mpaa_rating==4

*Perpatrator: Male
tab perp_male
tab perp_male if mpaa_rating==1
tab perp_male if mpaa_rating==2
tab perp_male if mpaa_rating==3
tab perp_male if mpaa_rating==4


//////////////////////////////VICTIM-LEVEL FACTORS/////////////////////////////

*use file: PoP.MainData.dta
*Victim: Protagonist
tab vic_protagonist
tab vic_protagonist if mpaa_rating==1
tab vic_protagonist if mpaa_rating==2
tab vic_protagonist if mpaa_rating==3
tab vic_protagonist if mpaa_rating==4

*Victim: Antagonist
tab vic_antagonist
tab vic_antagonist if mpaa_rating==1
tab vic_antagonist if mpaa_rating==2
tab vic_antagonist if mpaa_rating==3
tab vic_antagonist if mpaa_rating==4

*Victim Poses Threat
tab threat
tab threat if mpaa_rating==1
tab threat if mpaa_rating==2
tab threat if mpaa_rating==3
tab threat if mpaa_rating==4

*Victim Incapable of Complying
tab incapable
tab incapable if mpaa_rating==1
tab incapable if mpaa_rating==2
tab incapable if mpaa_rating==3
tab incapable if mpaa_rating==4

*Victim Female
tab victim_female
tab victim_female if mpaa_rating==1
tab victim_female if mpaa_rating==2
tab victim_female if mpaa_rating==3
tab victim_female if mpaa_rating==4

*Victim: White
tab vic_white
tab vic_white if mpaa_rating==1
tab vic_white if mpaa_rating==2
tab vic_white if mpaa_rating==3
tab vic_white if mpaa_rating==4



****************************RESULTS SECTION*************************************

////////////H1: Instrumental torture is effective most of the time////////////
ttest efficacy_rc==.5 
ttest efficacy_rc==.5 if mpaa_rating==1
ttest efficacy_rc==.5 if mpaa_rating==2
ttest efficacy_rc==.5 if mpaa_rating==3
ttest efficacy_rc==.5 if mpaa_rating==4


/////////////H2a: Protagonists are more likely than antagonists to/////////////
/////////////////////use torture for instrumental purposes/////////////////////
*Main
mlogit torture_goal_rc perp_protagonist_rc, baseoutcome(1)
	mlogit, rrr	
	
*Robustness Checks
*controlling for movie rating
mlogit torture_goal_rc perp_protagonist_rc mpaa_rating, baseoutcome(1)
	mlogit, rrr
*controlling for public official coding
mlogit torture_goal_rc perp_protagonist_rc public_official_coding, 
	//baseoutcome(1)
	mlogit, rrr
*public official coding only IV
mlogit torture_goal_rc public_official_coding, baseoutcome(1)
	mlogit, rrr		
*type of instrumental goal	
mlogit torture_instrumental_goal_type perp_protagonist_rc, baseoutcome(1)
	mlogit, rrr	
	
	
////////////H2b: Protagonists are likely likely than antagonists to////////////
///////////////////////use torture for punitive purposes///////////////////////
*Main
mlogit torture_goal_rc perp_protagonist_rc, baseoutcome(2)
	mlogit, rrr	
	
*Robustness Checks
*controlling for movie rating
mlogit torture_goal_rc perp_protagonist_rc mpaa_rating, baseoutcome(2)
	mlogit, rrr
*controlling for public official coding
mlogit torture_goal_rc perp_protagonist_rc public_official_coding, 
	//baseoutcome(2)
	mlogit, rrr
*public official coding only IV
mlogit torture_goal_rc public_official_coding, baseoutcome(2)
	mlogit, rrr		
*type of instrumental goal	
mlogit torture_instrumental_goal_type perp_protagonist_rc, baseoutcome(2)
	mlogit, rrr		
	
	
//////////H3: Protagonists are more likely than antagonists to torture//////////
///////////////////in response to a specific, existing threat///////////////////
*Main	
ttest threat, by(perp_protagonist_rc)
	esize twosample threat, by(perp_protagonist_rc) all

*Robustness Checks: Alternative Modeling Decisions
tabulate threat perp_protagonist_rc, chi2
prtest threat, by(perp_protagonist_rc)
	
	
//H4: Protagonists are more likely than antagonists to be effective at torture//
*Main	
ttest efficacy_rc, by(perp_protagonist_rc)
	esize twosample efficacy_rc, by(perp_protagonist_rc) all

*Robustness Checks: Alternative Modeling Decisions
tabulate efficacy_rc perp_protagonist_rc, chi2  
prtest efficacy_rc, by(perp_protagonist_rc)

	
///////H5: Protagonists are less likely than antagonists to torture women/////// 
*Main
ttest victim_female, by(perp_protagonist_rc)
	esize twosample victim_female, by(perp_protagonist_rc) all
	
*Robustness Checks: Alternative Modeling Decisions
tabulate victim_female perp_protagonist_rc, chi2
prtest victim_female, by(perp_protagonist_rc)


/////////H6: Protagonists are likely likely than antagonists to torture/////////
//////////////////////people who are incapable of complying/////////////////////
*Main
ttest incapable, by(perp_protagonist_rc)

*Robustness Checks: Alternative Modeling Decisions
tabulate incapable perp_protagonist_rc, chi2
prtest incapable, by(perp_protagonist_rc)

